<?php
/**
 * Theme Customization
 * Use theme_mod(Theme Modification)
 *
 * @version 1.0.0
 * @since   1.0.0
 * @see
 * https://codex.wordpress.org/Theme_Customization_API
 * color priority
 * https://wptheming.com/2012/06/add-options-to-theme-customizer-default-sections/
 */

/**
 * Set Theme Customization API
 *
 * @param object $wp_customize customizer object from WordPress system.
 *
 * @since 1.0.0
 */
function kanagata_customize_register( $wp_customize ) {
	 /*
	* title_tagline - Site Title & Tagline (and Site Icon in WP 4.3+)
	* colors - Colors
	* header_image - Header Image
	* background_image - Background Image
	* nav - Navigation
	* static_front_page - Static Front Page
	*/
	/*
	* title_tagline section
	*/
	/* site title */
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	/* Site title color */
	$wp_customize->add_setting(
		'site_title_color',
		array(
			'default'           => '#337ab7',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'site_title_color',
			array(
				'label'    => __( 'color', 'kanagata' ),
				'section'  => 'title_tagline',
				'settings' => 'site_title_color',
			)
		)
	);
	/* Di:wsplay site title when display logo. */
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	/*
	* Colors section（Priority 20）
	*/
	// Global menu.
	$wp_customize->add_setting(
		'menu-global-background_color',
		array(
			'default'           => '#ffffff',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'menu-global-background_color',
			array(
				'label'    => __( 'Global menu', 'kanagata' ),
				'section'  => 'colors',
				'settings' => 'menu-global-background_color',
			)
		)
	);
	// Global menu dropdown list.
	$wp_customize->add_setting(
		'menu_global_dropdown',
		array(
			'default'           => '#ffffff',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'menu_global_dropdown',
			array(
				'label'    => __( 'Global menu dropdown', 'kanagata' ),
				'section'  => 'colors',
				'settings' => 'menu_global_dropdown',
			)
		)
	);
	// Extra menu.
	$wp_customize->add_setting(
		'menu-extra-background_color',
		array(
			'default'           => '#ffffff',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'menu-extra-background_color',
			array(
				'label'    => __( 'Extra menu', 'kanagata' ),
				'section'  => 'colors',
				'settings' => 'menu-extra-background_color',
			)
		)
	);
	// Extra menu dropdown list.
	$wp_customize->add_setting(
		'menu_extra_dropdown',
		array(
			'default'           => '#ffffff',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'menu_extra_dropdown',
			array(
				'label'    => __( 'Extra menu dropdown', 'kanagata' ),
				'section'  => 'colors',
				'settings' => 'menu_extra_dropdown',
			)
		)
	);
	// Sidebar.
	$wp_customize->add_setting(
		'sidebar_background_color',
		array(
			'default'           => '#ffffff',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'sidebar_background_color',
			array(
				'label'    => __( 'Sidebar', 'kanagata' ),
				'section'  => 'colors',
				'settings' => 'sidebar_background_color',
			)
		)
	);
	// Pager.
	$wp_customize->add_setting(
		'pager_background_color',
		array(
			'default'           => '#e1e1e1',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'pager_background_color',
			array(
				'label'    => __( 'Pager', 'kanagata' ),
				'section'  => 'colors',
				'settings' => 'pager_background_color',
			)
		)
	);

	/*
	 * Archive layout section.
	 */
	$wp_customize->add_section(
		'archive_layout',
		array(
			'title'    => __( 'Archive Layout', 'kanagata' ),
			'priority' => 21,
		)
	);
	$wp_customize->add_setting(
		'archive_layout',
		array(
			'default'           => 'full',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'kanagata_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'archive_layout',
		array(
			'label'    => __( 'Select archive style', 'kanagata' ),
			'section'  => 'archive_layout',
			'settings' => 'archive_layout',
			'type'     => 'radio',
			'choices'  => array(
				'full' => __( 'Full', 'kanagata' ),
				'list' => __( 'List', 'kanagata' ),
				'card' => __( 'Card', 'kanagata' ),
			),
		)
	);
	// Background image.
	// @see https://gist.github.com/ejointjp/d64fb2d2a71b7d2d2b67ef0849971d6e
	$wp_customize->add_setting(
		'archive_default_thumbnail',
		array(
			'default'           => '',
			'priority'          => 1000,
			'transport'         => 'postMessage',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'archive_default_thumbnail_id',
			array(
				'section'  => 'archive_layout',
				'settings' => 'archive_default_thumbnail',
				'label'    => __( 'Default thumbnail image', 'kanagata' ),
			)
		)
	);

	/*
	* Sidebar layout section.
	*/
	$wp_customize->add_section(
		'sidebar_layout_section',
		array(
			'title'    => __( 'Sidebar Layout', 'kanagata' ),
			'priority' => 21,
		)
	);
	$wp_customize->add_setting(
		'sidebar_layout',
		array(
			'default'           => 'right',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'kanagata_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'sidebar_layout',
		array(
			'label'    => __( 'Select sidebar Position', 'kanagata' ),
			'section'  => 'sidebar_layout_section',
			'settings' => 'sidebar_layout',
			'type'     => 'radio',
			'choices'  => array(
				'right'  => __( 'Right sidebar', 'kanagata' ),
				'left'   => __( 'Left sidebar', 'kanagata' ),
				'bottom' => __( 'Bottom sidebar', 'kanagata' ),
			),
		)
	);

	/*
	* Jumbotron
	*/
	$wp_customize->add_section(
		'jumbotron',
		array(
			'title'       => __( 'Jumbotron', 'kanagata' ),
			'description' => __(
				'Top page jumbotron settings.',
				'kanagata'
			),
			'priority'    => 22,
		)
	);
	// Enable
	$wp_customize->add_setting(
		'jumbotron__enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'jumbotron__enable',
			array(
				'label'    => __( 'Enable', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'jumbotron',
				'settings' => 'jumbotron__enable',
			)
		)
	);
	// Background color.
	$wp_customize->add_setting(
		'jumbotron_background_color',
		array(
			'default'           => '#ffffff',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'jumbotron_background_color',
			array(
				'label'    => __( 'Background color', 'kanagata' ),
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_background_color',
			)
		)
	);
	// Background gradient enable.
	$wp_customize->add_setting(
		'jumbotron_background_gradient_enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'jumbotron_background_gradient_enable',
			array(
				'label'    => __( 'Background gradation Enable', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_background_gradient_enable',
			)
		)
	);
	// Background gradient start
	$wp_customize->add_setting(
		'jumbotron_background_gradient_start',
		array(
			'default'           => '#000000',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'jumbotron_background_gradient_start',
			array(
				'label'    => __( 'Background gradation top color', 'kanagata' ),
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_background_gradient_start',
			)
		)
	);
	// Background gradient end
	$wp_customize->add_setting(
		'jumbotron_background_gradient_end',
		array(
			'default'           => '#555555',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'jumbotron_background_gradient_end',
			array(
				'label'    => __( 'Background gradation bottom color', 'kanagata' ),
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_background_gradient_end',
			)
		)
	);

	// Background image.
	// @see https://gist.github.com/ejointjp/d64fb2d2a71b7d2d2b67ef0849971d6e
	$wp_customize->add_setting(
		'jumbotron_background_image',
		array(
			'default'           => '',
			'priority'          => 1000,
			'transport'         => 'postMessage',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'themename_control_image_id',
			array(
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_background_image',
				'label'    => __( 'Background image', 'kanagata' ),
			)
		)
	);
	// Text
	$wp_customize->add_setting(
		'jumbotron_text',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'kanagata_sanitize_textarea',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'jumbotron_text',
			array(
				'label'    => __( 'Text', 'kanagata' ),
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_text',
				'type'     => 'textarea',
			)
		)
	);
	// Text Color
	$wp_customize->add_setting(
		'jumbotron_text_color',
		array(
			'default'           => '#333333',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'jumbotron_text_color',
			array(
				'label'    => __( 'Text color', 'kanagata' ),
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_text_color',
			)
		)
	);
	// Text size.
	$wp_customize->add_setting(
		'jumbotron_text_size',
		array(
			'default'           => '48px',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'jumbotron_text_size',
			array(
				'label'    => __( 'Text size', 'kanagata' ),
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_text_size',
				'type'     => 'text',
			)
		)
	);
	// Text shadow
	$wp_customize->add_setting(
		'jumbotron_text_shadow',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'jumbotron_text_shadow',
			array(
				'label'    => __( 'Text shadow', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'jumbotron',
				'settings' => 'jumbotron_text_shadow',
			)
		)
	);

	/*
	* Copyight section.
	*/
	$wp_customize->add_section(
		'copyright_section',
		array(
			'title'    => __( 'Copyright', 'kanagata' ),
			'priority' => 200,
		)
	);
	// Copy right in footer.
	$wp_customize->add_setting(
		'footer_copyright',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'footer_copyright',
			array(
				'label'    => __( 'copy right', 'kanagata' ),
				'section'  => 'copyright_section',
				'settings' => 'footer_copyright',
			)
		)
	);

    /*
     * Heading style.
     */
    $wp_customize->add_panel( 'heading_style', array(
        'title' => __( 'Heading Style', 'kanagata' ),
        'description' => 'Heading style.',
        'priority' => 200,
    ) );
    /*
     * Heading type.
     */
	$wp_customize->add_section(
		'style_type',
		array(
			'title'       => __( 'Heading type', 'kanagata' ),
			'description' => __(
				'You will select the heading style.',
				'kanagata'
			),
            'priority'    => 1,
            'panel' => 'heading_style',
		)
    );
    $wp_customize->add_setting(
		'style_type',
		array(
			'title'       => __( 'Heading type', 'kanagata' ),
			'default'           => 'default',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
            'sanitize_callback' => 'kanagata_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'style_type',
		array(
			'label'    => __( 'Select heading type', 'kanagata' ),
			'section'  => 'style_type',
			'settings' => 'style_type',
			'type'     => 'radio',
			'choices'  => array(
				'heading-style-default' => __( 'default', 'kanagata' ),
				'heading-style-primary' => __( 'primary', 'kanagata' ),
				'heading-style-secondary' => __( 'secondary', 'kanagata' ),
			),
		)
	);
	/*
	 * Heading font size, margin top, button
	 */
	$wp_customize->add_section(
		'style_size',
		array(
			'title'       => __( 'Heading size', 'kanagata' ),
			'description' => __(
				'You will do the settings for size. Please enter , including the unit(e.g px, em, rem).',
				'kanagata'
			),
            'priority'    => 2,
            'panel' => 'heading_style',
		)
	);
	/*
	Singular title */
	// Singular title is single page title and static page title and archive page title.
	// Notice：Archive page tilte is not posts title in archive).
	// Font size.
	$wp_customize->add_setting(
		'singular_title',
		array(
			'default'           => '30px',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'singular_title',
			array(
				'label'    => __( 'Singular page title font size', 'kanagata' ),
				'section'  => 'style_size',
				'settings' => 'singular_title',
				'priority' => 1,
			)
		)
	);
	$wp_customize->add_setting(
		'singular_title_enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'singular_title_enable',
			array(
				'label'    => __( 'enable Singular page title font size setting.', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'style_size',
				'settings' => 'singular_title_enable',
				'priority' => 2,
			)
		)
	);
	// Margin top.
	$wp_customize->add_setting(
		'singular_title_margin_top',
		array(
			'default'           => '0',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'singular_title_margin_top',
			array(
				'label'    => __( 'Singular page title top margin size', 'kanagata' ),
				'section'  => 'style_size',
				'settings' => 'singular_title_margin_top',
				'priority' => 3,
			)
		)
	);
	$wp_customize->add_setting(
		'singular_title_margin_top_enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'singular_title_margin_top_enable',
			array(
				'label'    => __( 'enable Singular page title top margin size.', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'style_size',
				'settings' => 'singular_title_margin_top_enable',
				'priority' => 4,
			)
		)
	);
	// Margin bottom.
	$wp_customize->add_setting(
		'singular_title_margin_bottom',
		array(
			'default'           => '32px',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'singular_title_margin_bottom',
			array(
				'label'    => __( 'Singular page title bottom margin size', 'kanagata' ),
				'section'  => 'style_size',
				'settings' => 'singular_title_margin_bottom',
				'priority' => 5,
			)
		)
	);
	$wp_customize->add_setting(
		'singular_title_margin_bottom_enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'singular_title_margin_bottom_enable',
			array(
				'label'    => __( 'enable Singular page title bottom margin size.', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'style_size',
				'settings' => 'singular_title_margin_bottom_enable',
				'priority' => 6,
			)
		)
	);
	/*
	post title */
	// Font size.
	$wp_customize->add_setting(
		'post_title',
		array(
			'default'           => '30px',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'post_title',
			array(
				'label'    => __( 'Post title font size', 'kanagata' ),
				'section'  => 'style_size',
				'settings' => 'post_title',
				'priority' => 7,
			)
		)
	);
	$wp_customize->add_setting(
		'post_title_enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'post_title_enable',
			array(
				'label'    => __( 'Enable post title font size.', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'style_size',
				'settings' => 'post_title_enable',
				'priority' => 8,
			)
		)
	);
	// Margin top.
	$wp_customize->add_setting(
		'post_title_margin_top',
		array(
			'default'           => '56px',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'post_title_margin_top',
			array(
				'label'    => __( 'Post title top margin size', 'kanagata' ),
				'section'  => 'style_size',
				'settings' => 'post_title_margin_top',
				'priority' => 9,
			)
		)
	);
	$wp_customize->add_setting(
		'post_title_margin_top_enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'post_title_margin_top_enable',
			array(
				'label'    => __( 'Enable post title top margin size.', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'style_size',
				'settings' => 'post_title_margin_top_enable',
				'priority' => 10,
			)
		)
	);
	// Margin bottom.
	$wp_customize->add_setting(
		'post_title_margin_bottom',
		array(
			'default'           => '32px',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'post_title_margin_bottom',
			array(
				'label'    => __( 'Post title bottom margin size', 'kanagata' ),
				'section'  => 'style_size',
				'settings' => 'post_title_margin_bottom',
				'priority' => 11,
			)
		)
	);
	$wp_customize->add_setting(
		'post_title_margin_bottom_enable',
		array(
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'post_title_margin_bottom_enable',
			array(
				'label'    => __( 'Enable post title bottom margin size.', 'kanagata' ),
				'type'     => 'checkbox',
				'section'  => 'style_size',
				'settings' => 'post_title_margin_bottom_enable',
				'priority' => 12,
			)
		)
	);

	/*
	* Link section.
	*/
	// Link color.
	$wp_customize->add_section(
		'link_section',
		array(
			'title'       => __( 'Site Link style', 'kanagata' ),
			'priority'    => 201,
			'description' => __( 'Select site Link style', 'kanagata' ),
		)
	);
	$wp_customize->add_setting(
		'link_a_color',
		array(
			'default'           => '#337ab7',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'link_a_color',
			array(
				'label'    => __( 'link color', 'kanagata' ),
				'section'  => 'link_section',
				'settings' => 'link_a_color',
			)
		)
	);
	$wp_customize->add_setting(
		'link_a_link_color',
		array(
			'default'           => '#23527c',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'link_a_link_color',
			array(
				'label'    => __( 'Non-visit link color', 'kanagata' ),
				'section'  => 'link_section',
				'settings' => 'link_a_link_color',
			)
		)
	);
	$wp_customize->add_setting(
		'link_a_active_color',
		array(
			'default'           => '#337ab7',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'link_a_active_color',
			array(
				'label'    => __( 'Press link color', 'kanagata' ),
				'section'  => 'link_section',
				'settings' => 'link_a_active_color',
			)
		)
	);
	$wp_customize->add_setting(
		'link_a_visited_color',
		array(
			'default'           => '#337ab7',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'link_a_visited_color',
			array(
				'label'    => __( 'Visited link color', 'kanagata' ),
				'section'  => 'link_section',
				'settings' => 'link_a_visited_color',
			)
		)
	);
	$wp_customize->add_setting(
		'link_a_hover_color',
		array(
			'default'           => '#23527c',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'link_a_hover_color',
			array(
				'label'    => __( 'Mouse over link color', 'kanagata' ),
				'section'  => 'link_section',
				'settings' => 'link_a_hover_color',
			)
		)
	);
	// Link underline.
	$wp_customize->add_setting(
		'text_decoration',
		array(
			'default'           => 'underline',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'kanagata_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'text_decoration',
		array(
			'label'    => __(
				'Whether or not display link underline.',
				'kanagata'
			),
			'section'  => 'link_section',
			'settings' => 'text_decoration',
			'type'     => 'radio',
			'choices'  => array(
				'underline' => __( 'Yes', 'kanagata' ),
				'none'      => __( 'No', 'kanagata' ),
			),
		)
	);

	/*
	* Post meta information.
	*/
	$wp_customize->add_section(
		'post_meta_section',
		array(
			'title'       => __( 'Select to display post meta', 'kanagata' ),
			'priority'    => 203,
			'description' => __(
				'Select whether or not to display post meta.',
				'kanagata'
			),
		)
	);
	$wp_customize->add_setting(
		'post_meta',
		array(
			'default'           => 'yes',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'kanagata_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'post_meta',
		array(
			'label'    => __( 'post meta', 'kanagata' ),
			'section'  => 'post_meta_section',
			'settings' => 'post_meta',
			'type'     => 'radio',
			'choices'  => array(
				'yes' => __( 'Yes', 'kanagata' ),
				'no'  => __( 'No', 'kanagata' ),
			),
		)
	);

	/*
	* Top page post list.
	*/
	$wp_customize->add_section(
		'specific_category_section',
		array(
			'title'       => __( 'Category list displaying top page', 'kanagata' ),
			'priority'    => 203,
			'description' => __(
				'Input specific category name. that category post is shown on the top page as a list.',
				'kanagata'
			),
		)
	);
	// Specific_category_name.
	$wp_customize->add_setting(
		'specific_category_name',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'specific_category_name',
			array(
				'label'    => __( 'Category name', 'kanagata' ),
				'section'  => 'specific_category_section',
				'settings' => 'specific_category_name',
			)
		)
	);
	// Specific_category_num.
	$wp_customize->add_setting(
		'specific_category_num',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'specific_category_num',
			array(
				'label'    => __( 'Item number included in the list', 'kanagata' ),
				'section'  => 'specific_category_section',
				'settings' => 'specific_category_num',
			)
		)
	);
	$wp_customize->add_setting(
		'display_latest_post',
		array(
			'default'           => 'yes',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'kanagata_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'display_latest_post',
		array(
			'label'    => __(
				'Whether or not display regular latest post when you display Specific category list.',
				'kanagata'
			),
			'section'  => 'specific_category_section',
			'settings' => 'display_latest_post',
			'type'     => 'radio',
			'choices'  => array(
				'yes' => __( 'Yes', 'kanagata' ),
				'no'  => __( 'No', 'kanagata' ),
			),
		)
	);

	/*
	* Slide header image (default header image section).
	*/
	$wp_customize->add_setting(
		'slide_header_image',
		array(
			'default'           => 'no',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'kanagata_sanitize_select',
		)
	);
	$wp_customize->add_control(
		'slide_header_image',
		array(
			'label'    => __(
				'Select whether or not header image is slide.',
				'kanagata'
			),
			'section'  => 'header_image',
			'settings' => 'slide_header_image',
			'type'     => 'radio',
			'choices'  => array(
				'yes' => __( 'Yes', 'kanagata' ),
				'no'  => __( 'No', 'kanagata' ),
			),
		)
	);
}

add_action( 'customize_register', 'kanagata_customize_register' );

/**
 * Get option value using kanagata theme.
 *
 * Option doesn't use from version 1.3.
 * Only checking for compatibility.
 *
 * @param string $name option name.
 *
 * @return mixed
 * @since  1.0.0
 */
function kanagata_get_theme_option_value( $name ) {
	$options = get_option(
		'kanagata_theme_options',
		array(
			'layout'                 => 'right',
			'side_color'             => '',
			'specific_category_name' => '',
			'specific_category_num'  => '5',
			'display_latest_post'    => 'yes',
		)
	);
	return $options[ $name ];
}

/**
* Customize preview.
*
* @see add_action('customize_preview_init',$func)
*/
add_action(
	'customize_preview_init',
	function () {
		wp_enqueue_script(
			'customize',
			get_template_directory_uri() . '/js/customize.js',
			array( 'jquery', 'customize-preview' ),  // depends requirement scripts.
			'1.0.0',
			true
		);
	}
);
