<?php
/**
 * WooCommerce
 *
 * @see
 * https://docs.woocommerce.com/document/woocommerce-theme-developer-handbook/
 *
 * @since   3.1.3
 * @version 1.0.0
 */

add_action(
	'after_setup_theme',
	function () {
        add_theme_support( 'woocommerce' );
	},
	10
);

/**
 * Display category image in category archive
 * 
 * @see
 * https://docs.woocommerce.com/document/woocommerce-display-category-image-on-category-archive/
 */
add_action( 'woocommerce_archive_description', function() {
    if ( is_product_category() ){
	    global $wp_query;
	    $cat = $wp_query->get_queried_object();
	    $thumbnail_id = get_term_meta( $cat->term_id, 'thumbnail_id', true );
	    $image = wp_get_attachment_url( $thumbnail_id );
	    if ( $image ) {
		    echo '<img src="' . $image . '" alt="' . $cat->name . '" />';
		}
	}
}, 2);

// Add conteaier that contain product and sidebar in Shop and archive page.
add_action('woocommerce_before_shop_loop', function() {
    echo '<div class="woocommerce-shop-loop-container">';
});


// Add sidebar to woocommerce-shop-loop-container in shop and archive page.
add_action('woocommerce_after_shop_loop', function() {
    echo get_sidebar();
});

// Add container that contain product and sidebar in Single page.
add_action('woocommerce_before_main_content', function() {
    echo '<div class="woocommerce-shop-loop-container">';
});

// Add sidebar to woocommerce-shop-loop-container in Single page.
add_action('woocommerce_after_main_content', function() {
    echo get_sidebar();
}, 5);

// Prevent to call sidebar by woocommerce_sidebar hook.
remove_action('woocommerce_sidebar', 'woocommerce_get_sidebar', 10);